<?php

namespace Drupal\lb_routing\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\lb_routing\LayoutBuilderRoutingServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides local task definitions for lb_routing.
 *
 * @see \Drupal\layout_builder\Plugin\Derivative\LayoutBuilderLocalTaskDeriver
 *
 * @internal
 *   Plugin derivers are internal.
 */
class LayoutBuilderRoutingLocalTaskDeriver extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The Layout Builder routing service.
   *
   * @var \Drupal\lb_routing\LayoutBuilderRoutingServiceInterface
   */
  protected $routingService;

  /**
   * Constructs a new LayoutBuilderRoutingLocalTaskDeriver.
   *
   * @param \Drupal\lb_routing\LayoutBuilderRoutingServiceInterface $lb_routing_service
   *   The Layout Builder routing service.
   */
  public function __construct(LayoutBuilderRoutingServiceInterface $lb_routing_service) {
    $this->routingService = $lb_routing_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('lb_routing.service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    foreach ($this->routingService->getEnabledRoutes() as $route_name) {
      $this->derivatives["lb_builder.$route_name"] = $base_plugin_definition + [
          'route_name' => "$route_name",
          'title' => $this->t("Content ($route_name)"),
          'base_route' => "$route_name",
          'weight' => 0,
        ];
      $this->derivatives["lb_builder.lb_routing_config_simple.view.$route_name"] = $base_plugin_definition + [
          'route_name' => "layout_builder.lb_routing_config_simple.view",
          'title' => $this->t("Layout ($route_name)"),
          'base_route' => "$route_name",
          'route_parameters' => ['id' => $route_name],
          'weight' => 10,
        ];
    }

    return $this->derivatives;
  }

}
