<?php

namespace Drupal\lb_routing\Routing;

use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\lb_routing\Controller\LayoutBuilderRoutingController;
use Drupal\lb_routing\LayoutBuilderRoutingServiceInterface;
use Symfony\Cmf\Component\Routing\RouteObjectInterface;
use Symfony\Component\Routing\RouteCollection;

/**
 * Listens to the dynamic route events.
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The Layout Builder routing service.
   *
   * @var \Drupal\lb_routing\LayoutBuilderRoutingServiceInterface
   */
  protected $routingService;

  /**
   * Constructs a new RouteSubscriber object.
   *
   * @param \Drupal\lb_routing\LayoutBuilderRoutingServiceInterface $lb_routing_service
   *   The Layout Builder routing service.
   */
  public function __construct(LayoutBuilderRoutingServiceInterface $lb_routing_service) {
    $this->routingService = $lb_routing_service;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    $route_names = $this->routingService->getEnabledRoutes();
    foreach ($route_names as $route_name) {
      if ($route = $collection->get($route_name)) {
        $route->setDefaults([RouteObjectInterface::CONTROLLER_NAME => LayoutBuilderRoutingController::class . '::render']);
      }
    }
  }

}
